From 3d5438391785771772e23da483fce983e9d6875e Mon Sep 17 00:00:00 2001
From: basOS G <noxelia 4t gmail , com>
Date: Mon, 29 Dec 2008 23:18:09 +0200
Subject: [PATCH] [Mod] Changed snapshot naming format to be prefix-YYMMDD-HHmms.ext

Snapshot files are named after the current local date

rev 5
---
 src/video_output/vout_intf.c |   40 +++++++++++++++++++++++++++++++++-------
 1 files changed, 33 insertions(+), 7 deletions(-)

diff --git a/src/video_output/vout_intf.c b/src/video_output/vout_intf.c
index 90a95c9..2e0dc6b 100644
--- a/src/video_output/vout_intf.c
+++ b/src/video_output/vout_intf.c
@@ -36,6 +36,7 @@
 #include <sys/stat.h>
 #include <dirent.h>                                             /* opendir() */
 #include <assert.h>
+#include <time.h>                                           /* strftime */
 
 #include <vlc_interface.h>
 #include <vlc_block.h>
@@ -793,17 +794,42 @@ int vout_Snapshot( vout_thread_t *p_vout, picture_t *p_pic )
         }
         else
         {
-            if( asprintf( &psz_filename, "%s" DIR_SEP "%s%u.%s",
+            struct tm*    curtime;
+            time_t        lcurtime ;
+            lcurtime = time( NULL ) ;
+            if ( ( (curtime = localtime( &lcurtime )) == NULL ) )
+            {
+                msg_Warn( p_vout, "failed to get current time. Falling back to legacy snapshot naming" );
+                /* failed to get current time. Fallback to old format */
+                if( asprintf( &psz_filename, "%s" DIR_SEP "%s%u.%s",
                           val.psz_string, psz_prefix,
                           (unsigned int)(p_pic->date / 100000) & 0xFFFFFF,
                           format.psz_string ) == -1 )
-            {
-                msg_Err( p_vout, "could not create snapshot" );
-                image_HandlerDelete( p_image );
-                return VLC_EGENERIC;
+                {
+                    msg_Err( p_vout, "could not create snapshot" );
+                    image_HandlerDelete( p_image );
+                    return VLC_EGENERIC;
+                }
             }
-        }
-
+            else
+            {
+                char psz_curtime[15] ;
+                if( strftime( psz_curtime, 15, "%y%m%d-%H%M%S", curtime ) == 0 )
+                {
+                    msg_Warn( p_vout, "snapshot date string truncated" ) ;
+                }
+                if( asprintf( &psz_filename, "%s" DIR_SEP "%s%s%1u.%s",
+                      val.psz_string, psz_prefix, psz_curtime,
+                     /* suffix with the last decimal digit in 10s of seconds resolution */
+                     (unsigned int)(p_pic->date / 100*1000) & 0xFF,
+                      format.psz_string ) == -1 )
+                {
+                    msg_Err( p_vout, "could not create snapshot" );
+                    image_HandlerDelete( p_image );
+                    return VLC_EGENERIC;
+                }
+            } //end if time() < 0
+        } //end snapshot sequential
         free( psz_prefix );
     }
     else // The user specified a full path name (including file name)
-- 
1.5.4.3

